Meta Package Manager — Meta Package Manager 2.3.0 documentation

# Meta Package Manager

A CLI and a BitBar plugin to simplify software upgrades from several package managers.

Stable release:

Development:

Source: XKCD #1654.

## Features

- Search and list all package managers on the system.
- List outdated packages.
- Sync local package infos.
- Upgrade all outdated packages.

## Supported package managers

Package manager | macOS | Linux | Windows | Version
--- | --- | --- | --- | ---
Homebrew | ✅ |  |  | >= 1.0.*
Homebrew Cask | ✅ |  |  | >= 1.0.*
Python 2 `pip` | ✅ | ✅ |  |
Python 3 `pip` | ✅ | ✅ |  |
Node’s `npm` | ✅ |  |  |
Atom’s `apm` | ✅ |  |  |
Ruby’s `gem` | ✅ |  |  |
Mac AppStore via `mas` | ✅ |  |  | >= 1.3.1

If you’re bored, feel free to add support for new package manager. See the list of good candidates.

## Usage

Examples of the package’s `mpm` CLI.

List global options and commands:

    $ mpm
    Usage: mpm [OPTIONS] COMMAND [ARGS]...

      CLI for multi-package manager upgrades.

    Options:
      -v, --verbosity LEVEL           Either CRITICAL, ERROR, WARNING, INFO or
                                      DEBUG. Defaults to INFO.
      -m, --manager [npm|mas|pip3|pip2|cask|apm|brew|gem]
                                      Restrict sub-command to one package manager.
                                      Defaults to all.
      -o, --output-format [simple|plain|json|fancy]
                                      Rendering mode of the output. Defaults to
                                      fancy.
      --version                       Show the version and exit.
      --help                          Show this message and exit.

    Commands:
      managers  List supported package managers and their location.
      outdated  List outdated packages.
      sync      Sync local package info.
      upgrade   Upgrade all packages.

List all supported package managers and their status on current system:

    $ mpm managers
    ╒═══════════════════╤══════╤═════════════════════╤═════════╤══════════════╤═══════════╕
    │ Package manager   │ ID   │ CLI path            │ Found   │ Executable   │ Version   │
    ╞═══════════════════╪══════╪═════════════════════╪═════════╪══════════════╪═══════════╡
    │ Atom's apm        │ apm  │ /usr/local/bin/apm  │ ✅       │ ✅            │ ✅         │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Homebrew          │ brew │ /usr/local/bin/brew │ ✅       │ ✅            │ ✅  1.1.2  │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Homebrew Cask     │ cask │ /usr/local/bin/brew │ ✅       │ ✅            │ ✅  1.1.2  │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Ruby Gems         │ gem  │ /usr/bin/gem        │ ✅       │ ✅            │ ✅         │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Mac AppStore      │ mas  │ /usr/local/bin/mas  │ ✅       │ ✅            │ ✅  1.3.1  │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Node's npm        │ npm  │ /usr/local/bin/npm  │ ✅       │ ✅            │ ✅         │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Python 2's Pip    │ pip2 │ /usr/local/bin/pip2 │ ✅       │ ✅            │ ✅         │
    ├───────────────────┼──────┼─────────────────────┼─────────┼──────────────┼───────────┤
    │ Python 3's Pip    │ pip3 │ /usr/local/bin/pip3 │ ✅       │ ✅            │ ✅         │
    ╘═══════════════════╧══════╧═════════════════════╧═════════╧══════════════╧═══════════╛

## BitBar plugin

A copy of the latest stable version of the Meta Package Manager BitBar plugin is always available on BitBar website and plugin repository.

## Current status

Active development of the script is continuing here, in the exact same conditions as we were before moving the repository, like nothing happened.

Each time we reach a releaseable script, we simply tag it and push a copy to the BitBar plugin repository. Plain and simple.

At the same time we maintain a Python library on the side. The library is going to handle all idiosyncracies of supported package managers under a unified API.

Once the library is good enough, we’ll evaluate rebasing the original plugin on it, and lay out a plan for a painless transition, from the standalone script to a bare BitBar-plugin depending on the library alone.

In the mean time we have to temporarily manage duplicate code. But at least the whole project is kept in one centralized place, trying to tackle the same issues.

# Contents

- Installation
- meta_package_manager package
  - Subpackages
  - Submodules
  - meta_package_manager.base module
  - meta_package_manager.cli module
  - meta_package_manager.platform module
  - Module contents
- Development
  - Philosophy
  - Stability policy
  - Build status
  - Setup a development environment
  - Unit-tests
  - Coding style
  - Build documentation
  - Release process
- Changelog
  - 2.3.0 (unreleased)
  - 2.2.0 (2016-12-25)
  - 2.1.1 (2016-12-17)
  - 2.1.0 (2016-12-14)
  - 2.0.0 (2016-12-04)
  - 1.12.0 (2016-12-03)
  - 1.11.0 (2016-11-30)
  - 1.10.0 (2016-10-04)
  - 1.9.0 (2016-09-23)
  - 1.8.0 (2016-08-22)
  - 1.7.0 (2016-08-16)
  - 1.6.0 (2016-08-10)
  - 1.5.0 (2016-07-25)
  - 1.4.0 (2016-07-10)
  - 1.3.0 (2016-07-09)
  - 1.2.0 (2016-07-08)
  - 1.1.0 (2016-07-07)
  - 1.0.0 (2016-07-05)
- History
- License

# Indices and tables

- Index
- Module Index
- Search Page